┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/iconmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/iconmanager.h')
-rw-r--r--src/iconmanager.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/iconmanager.h b/src/iconmanager.h
index 2636c81c6..d6cf5332b 100644
--- a/src/iconmanager.h
+++ b/src/iconmanager.h
@@ -51,11 +51,11 @@ public:
private slots:
/**
* Generates a preview image for each file item in \a items.
* The current preview settings (maximum size, 'Show Preview' menu)
* are respected.
*/
- void generatePreviews(const KFileItemList& items);
+ void updateIcons(const KFileItemList& items);
/**
* Replaces the icon of the item \a item by the preview pixmap
@@ -82,6 +82,9 @@ private:
/** Applies an item effect to all cut items. */
void applyCutItemEffect();
+ /** Applies an item effect to the hidden item \a hiddenItem. */
+ void applyHiddenItemEffect(const KFileItem& hiddenItem);
+
private:
/**
* Remembers the original pixmap for an item before
@@ -51,11 +51,11 @@ public:
private slots:
/**
- * Generates a preview image for each file item in \a items.
- * The current preview settings (maximum size, 'Show Preview' menu)
- * are respected.
+ * Updates the icons of for each item in \a items by making hidden
+ * items semitransparent and generating previews. The current preview
+ * settings (maximum size, 'Show Preview' menu) are respected.
*/